( cd opt/kde/share/doc/HTML/ru/koshell ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/koshell ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kugar ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kugar ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/kword ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/kword ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/ru/thesaurus ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/thesaurus ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
